@@ -6,7 +6,8 @@
 
 #include "pgmsettings.h"
 #include <klocale.h>			/* i18n */
-#include <kapp.h>
+#include <kapplication.h>
+#include <qfileinfo.h>
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qlabel.h>
@@ -99,15 +100,10 @@ ProgramSettings::ProgramSettings(QWidget* parent, QString exeName, bool modal) :
 	m_output(this)
 {
     // construct title
-    int slash = exeName.findRev('/');
-    if (slash >= 0) {
-	exeName.remove(0, slash+1);
-    }
+    QFileInfo fi(exeName);
     QString cap = kapp->caption();
-    QString fmt = i18n("%s: Settings for %s");
-    QString title;
-    title.sprintf(fmt, cap.data(), exeName.data());
-    setCaption(title);
+    QString title = i18n("%1: Settings for %2");
+    setCaption(title.arg(cap, fi.fileName()));
 
     setCancelButton(i18n("Cancel"));
     setOKButton(i18n("OK"));
